==> openshift-model-5.9.0-sources.jar: io/fabric8/openshift/api/model/SubjectAccessReviewResponseBuilder.java <==
package io.fabric8.openshift.api.model;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;
public class SubjectAccessReviewResponseBuilder extends io.fabric8.openshift.api.model.SubjectAccessReviewResponseFluentImpl<io.fabric8.openshift.api.model.SubjectAccessReviewResponseBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.openshift.api.model.SubjectAccessReviewResponse,io.fabric8.openshift.api.model.SubjectAccessReviewResponseBuilder>{
  public SubjectAccessReviewResponseBuilder() {
    this(false);
  }
  public SubjectAccessReviewResponseBuilder(java.lang.Boolean validationEnabled) {
    this(new SubjectAccessReviewResponse(), validationEnabled);
  }
  public SubjectAccessReviewResponseBuilder(io.fabric8.openshift.api.model.SubjectAccessReviewResponseFluent<?> fluent) {
    this(fluent, false);
  }
  public SubjectAccessReviewResponseBuilder(io.fabric8.openshift.api.model.SubjectAccessReviewResponseFluent<?> fluent,java.lang.Boolean validationEnabled) {
    this(fluent, new SubjectAccessReviewResponse(), validationEnabled);
  }
  public SubjectAccessReviewResponseBuilder(io.fabric8.openshift.api.model.SubjectAccessReviewResponseFluent<?> fluent,io.fabric8.openshift.api.model.SubjectAccessReviewResponse instance) {
    this(fluent, instance, false);
  }
  public SubjectAccessReviewResponseBuilder(io.fabric8.openshift.api.model.SubjectAccessReviewResponseFluent<?> fluent,io.fabric8.openshift.api.model.SubjectAccessReviewResponse instance,java.lang.Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withAllowed(instance.getAllowed()); 
    fluent.withApiVersion(instance.getApiVersion()); 
    fluent.withEvaluationError(instance.getEvaluationError()); 
    fluent.withKind(instance.getKind()); 
    fluent.withNamespace(instance.getNamespace()); 
    fluent.withReason(instance.getReason()); 
    this.validationEnabled = validationEnabled; 
  }
  public SubjectAccessReviewResponseBuilder(io.fabric8.openshift.api.model.SubjectAccessReviewResponse instance) {
    this(instance,false);
  }
  public SubjectAccessReviewResponseBuilder(io.fabric8.openshift.api.model.SubjectAccessReviewResponse instance,java.lang.Boolean validationEnabled) {
    this.fluent = this; 
    this.withAllowed(instance.getAllowed()); 
    this.withApiVersion(instance.getApiVersion()); 
    this.withEvaluationError(instance.getEvaluationError()); 
    this.withKind(instance.getKind()); 
    this.withNamespace(instance.getNamespace()); 
    this.withReason(instance.getReason()); 
    this.validationEnabled = validationEnabled; 
  }
  io.fabric8.openshift.api.model.SubjectAccessReviewResponseFluent<?> fluent;
  java.lang.Boolean validationEnabled;
  public io.fabric8.openshift.api.model.SubjectAccessReviewResponse build() {
    SubjectAccessReviewResponse buildable = new SubjectAccessReviewResponse(fluent.getAllowed(),fluent.getApiVersion(),fluent.getEvaluationError(),fluent.getKind(),fluent.getNamespace(),fluent.getReason());
    return buildable;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    SubjectAccessReviewResponseBuilder that = (SubjectAccessReviewResponseBuilder) o;
    if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

    if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
  }
  
}

==> openshift-model-5.12.2-sources.jar: io/fabric8/openshift/api/model/SubjectAccessReviewResponseBuilder.java <==
package io.fabric8.openshift.api.model;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;
public class SubjectAccessReviewResponseBuilder extends io.fabric8.openshift.api.model.SubjectAccessReviewResponseFluentImpl<io.fabric8.openshift.api.model.SubjectAccessReviewResponseBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.openshift.api.model.SubjectAccessReviewResponse,io.fabric8.openshift.api.model.SubjectAccessReviewResponseBuilder>{
  public SubjectAccessReviewResponseBuilder() {
    this(false);
  }
  public SubjectAccessReviewResponseBuilder(java.lang.Boolean validationEnabled) {
    this(new SubjectAccessReviewResponse(), validationEnabled);
  }
  public SubjectAccessReviewResponseBuilder(io.fabric8.openshift.api.model.SubjectAccessReviewResponseFluent<?> fluent) {
    this(fluent, false);
  }
  public SubjectAccessReviewResponseBuilder(io.fabric8.openshift.api.model.SubjectAccessReviewResponseFluent<?> fluent,java.lang.Boolean validationEnabled) {
    this(fluent, new SubjectAccessReviewResponse(), validationEnabled);
  }
  public SubjectAccessReviewResponseBuilder(io.fabric8.openshift.api.model.SubjectAccessReviewResponseFluent<?> fluent,io.fabric8.openshift.api.model.SubjectAccessReviewResponse instance) {
    this(fluent, instance, false);
  }
  public SubjectAccessReviewResponseBuilder(io.fabric8.openshift.api.model.SubjectAccessReviewResponseFluent<?> fluent,io.fabric8.openshift.api.model.SubjectAccessReviewResponse instance,java.lang.Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withAllowed(instance.getAllowed()); 
    fluent.withApiVersion(instance.getApiVersion()); 
    fluent.withEvaluationError(instance.getEvaluationError()); 
    fluent.withKind(instance.getKind()); 
    fluent.withNamespace(instance.getNamespace()); 
    fluent.withReason(instance.getReason()); 
    fluent.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  public SubjectAccessReviewResponseBuilder(io.fabric8.openshift.api.model.SubjectAccessReviewResponse instance) {
    this(instance,false);
  }
  public SubjectAccessReviewResponseBuilder(io.fabric8.openshift.api.model.SubjectAccessReviewResponse instance,java.lang.Boolean validationEnabled) {
    this.fluent = this; 
    this.withAllowed(instance.getAllowed()); 
    this.withApiVersion(instance.getApiVersion()); 
    this.withEvaluationError(instance.getEvaluationError()); 
    this.withKind(instance.getKind()); 
    this.withNamespace(instance.getNamespace()); 
    this.withReason(instance.getReason()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  io.fabric8.openshift.api.model.SubjectAccessReviewResponseFluent<?> fluent;
  java.lang.Boolean validationEnabled;
  public io.fabric8.openshift.api.model.SubjectAccessReviewResponse build() {
    SubjectAccessReviewResponse buildable = new SubjectAccessReviewResponse(fluent.getAllowed(),fluent.getApiVersion(),fluent.getEvaluationError(),fluent.getKind(),fluent.getNamespace(),fluent.getReason());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    SubjectAccessReviewResponseBuilder that = (SubjectAccessReviewResponseBuilder) o;
    if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

    if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
  }
  
}
